@@ -12,11 +12,11 @@ def forvo(language, word, key):
 	page = get(url)
 	if page.status_code == 200:
 		if 'incorrect' in page.text:
-			from ..exceptions import IncorrectForvoAPIKey
+			from lltk.exceptions import IncorrectForvoAPIKey
 			raise IncorrectForvoAPIKey('Your Forvi API key seems to be wrong. Please check on http://api.forvo.com.')
 		data = page.json()
 		if data == ['Limit/day reached.']:
-			from ..exceptions import DailyForvoLimitExceeded
+			from lltk.exceptions import DailyForvoLimitExceeded
 			raise DailyForvoLimitExceeded('You have exceeded your daily Forvo API limit.')
 		if data.has_key('items') and len(data['items']):
 			items = sorted(data['items'], key = lambda x: int(x['num_votes']), reverse = True)
